@@ -1,5 +1,5 @@
 /* 
- * Copyright 1999-2005, Gisle Aas
+ * Copyright 1999-2009, Gisle Aas
  * Copyright 1999-2000, Michael A. Chase
  *
  * This library is free software; you can redistribute it and/or
@@ -113,7 +113,7 @@ struct p_state {
     /* other configuration stuff */
     SV* bool_attr_val;
     struct p_handler handlers[EVENT_COUNT];
-    bool argspec_entity_decode;
+    int argspec_entity_decode;
 
     /* filters */
     HV* report_tags;
