@@ -1,10 +1,8 @@
 package HTML::PullParser;
 
-# $Id: PullParser.pm,v 2.6 2001/04/02 23:26:18 gisle Exp $
-
 require HTML::Parser;
 @ISA=qw(HTML::Parser);
-$VERSION = sprintf("%d.%02d", q$Revision: 2.6 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "3.57";
 
 use strict;
 use Carp ();
@@ -161,33 +159,37 @@ to a scalar.  If a reference is passed then the value of this scalar
 should not be changed before all tokens have been extracted.
 
 Next the information to be returned for the different token types must
-be set up.  This is done by simply assosiating an argspec (as defined
-in L<HTML::Parser>) with the events you have an interrest in.  For
+be set up.  This is done by simply associating an argspec (as defined
+in L<HTML::Parser>) with the events you have an interest in.  For
 instance, if you want C<start> tokens to be reported as the string
 C<'S'> followed by the tagname and the attributes you might pass an
 C<start>-option like this:
 
-   $p = HTML::Parser-New( doc   => $doc_to_parse,
-                          start => '"S", tagname, @attr',
-                          end   => '"E", tagname',
-                        );
+   $p = HTML::PullParser->new(
+          doc   => $document_to_parse,
+          start => '"S", tagname, @attr',
+          end   => '"E", tagname',
+        );
 
 At last other C<HTML::Parser> options, like C<ignore_tags>, and
 C<unbroken_text>, can be passed in.  Note that you should not use the
-I<event>_h options to set up parser handlers.
+I<event>_h options to set up parser handlers.  That would confuse the
+inner logic of C<HTML::PullParser>.
 
 =item $token = $p->get_token
 
 This method will return the next I<token> found in the HTML document,
-or C<undef> at the end of the document.  The token is usually returned
-as an array reference.  The content of this array match the argspec
-set up during C<HTML::PullParser> construction.
+or C<undef> at the end of the document.  The token is returned as an
+array reference.  The content of this array match the argspec set up
+during C<HTML::PullParser> construction.
 
-=item $p->unget_token($token,...)
+=item $p->unget_token( @tokens )
 
 If you find out you have read too many tokens you can push them back,
 so that they are returned again the next time $p->get_token is called.
 
+=back
+
 =head1 EXAMPLES
 
 The 'eg/hform' script shows how we might parse the form section of
