@@ -1,5 +1,5 @@
 /* 
- * Copyright 1999-2006, Gisle Aas.
+ * Copyright 1999-2009, Gisle Aas.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the same terms as Perl itself.
@@ -96,7 +96,6 @@ decode_entities(pTHX_ SV* sv, HV* entity2char, bool expand_prefix)
 
 	if (s < end && *s == '#') {
 	    UV num = 0;
-	    UV prev = 0;
 	    int ok = 0;
 	    s++;
 	    if (s < end && (*s == 'x' || *s == 'X')) {
@@ -106,12 +105,11 @@ decode_entities(pTHX_ SV* sv, HV* entity2char, bool expand_prefix)
 		    if (!tmp)
 			break;
 		    num = num << 4 | ((tmp - PL_hexdigit) & 15);
-		    if (prev && num <= prev) {
+		    if (num > 0x10FFFF) {
 			/* overflow */
 			ok = 0;
 			break;
 		    }
-		    prev = num;
 		    s++;
 		    ok = 1;
 		}
@@ -119,17 +117,16 @@ decode_entities(pTHX_ SV* sv, HV* entity2char, bool expand_prefix)
 	    else {
 		while (s < end && isDIGIT(*s)) {
 		    num = num * 10 + (*s - '0');
-		    if (prev && num < prev) {
+		    if (num > 0x10FFFF) {
 			/* overflow */
 			ok = 0;
 			break;
 		    }
-		    prev = num;
 		    s++;
 		    ok = 1;
 		}
 	    }
-	    if (ok) {
+	    if (num && ok) {
 #ifdef UNICODE_HTML_PARSER
 		if (!SvUTF8(sv) && num <= 255) {
 		    buf[0] = (char) num;
@@ -137,6 +134,9 @@ decode_entities(pTHX_ SV* sv, HV* entity2char, bool expand_prefix)
 		    repl_len = 1;
 		    repl_utf8 = 0;
 		}
+		else if (num == 0xFFFE || num == 0xFFFF) {
+		    /* illegal */
+		}
 		else {
 		    char *tmp;
 		    if ((num & 0xFFFFFC00) == 0xDC00) {  /* low-surrogate */
